==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Refrig_PeriodicTasks_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Refrig_PeriodicTasks_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long agentmonitorservice_taskPeriodMillis;

  private final long cold1_FanCtrl_timer_taskPeriodMillis;

  private final long cold2_FanCtrl_timer_taskPeriodMillis;

  private final long compressor_state_taskPeriodMillis;

  private final long cryo3_FanCtrl_timer_taskPeriodMillis;

  private final long cryo5_FanCtrl_timer_taskPeriodMillis;

  private final long heartbeat_taskPeriodMillis;

  private final long monitor_check_taskPeriodMillis;

  private final long monitor_publish_taskPeriodMillis;

  private final long monitor_update_taskPeriodMillis;

  private final long runtimeinfo_taskPeriodMillis;

  private final long update_time_taskPeriodMillis;

  public Refrig_PeriodicTasks_timersConfigurationEvent(int priority, String version,
      long agentmonitorservice_taskPeriodMillis, long cold1_FanCtrl_timer_taskPeriodMillis,
      long cold2_FanCtrl_timer_taskPeriodMillis, long compressor_state_taskPeriodMillis,
      long cryo3_FanCtrl_timer_taskPeriodMillis, long cryo5_FanCtrl_timer_taskPeriodMillis,
      long heartbeat_taskPeriodMillis, long monitor_check_taskPeriodMillis,
      long monitor_publish_taskPeriodMillis, long monitor_update_taskPeriodMillis,
      long runtimeinfo_taskPeriodMillis, long update_time_taskPeriodMillis) {
    super (priority);
    this.version = version;
    this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
    this.cold1_FanCtrl_timer_taskPeriodMillis = cold1_FanCtrl_timer_taskPeriodMillis;
    this.cold2_FanCtrl_timer_taskPeriodMillis = cold2_FanCtrl_timer_taskPeriodMillis;
    this.compressor_state_taskPeriodMillis = compressor_state_taskPeriodMillis;
    this.cryo3_FanCtrl_timer_taskPeriodMillis = cryo3_FanCtrl_timer_taskPeriodMillis;
    this.cryo5_FanCtrl_timer_taskPeriodMillis = cryo5_FanCtrl_timer_taskPeriodMillis;
    this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
    this.monitor_check_taskPeriodMillis = monitor_check_taskPeriodMillis;
    this.monitor_publish_taskPeriodMillis = monitor_publish_taskPeriodMillis;
    this.monitor_update_taskPeriodMillis = monitor_update_taskPeriodMillis;
    this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
    this.update_time_taskPeriodMillis = update_time_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getAgentmonitorservice_taskPeriodMillis() {
    return agentmonitorservice_taskPeriodMillis;
  }

  public long getCold1_FanCtrl_timer_taskPeriodMillis() {
    return cold1_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCold2_FanCtrl_timer_taskPeriodMillis() {
    return cold2_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCompressor_state_taskPeriodMillis() {
    return compressor_state_taskPeriodMillis;
  }

  public long getCryo3_FanCtrl_timer_taskPeriodMillis() {
    return cryo3_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCryo5_FanCtrl_timer_taskPeriodMillis() {
    return cryo5_FanCtrl_timer_taskPeriodMillis;
  }

  public long getHeartbeat_taskPeriodMillis() {
    return heartbeat_taskPeriodMillis;
  }

  public long getMonitor_check_taskPeriodMillis() {
    return monitor_check_taskPeriodMillis;
  }

  public long getMonitor_publish_taskPeriodMillis() {
    return monitor_publish_taskPeriodMillis;
  }

  public long getMonitor_update_taskPeriodMillis() {
    return monitor_update_taskPeriodMillis;
  }

  public long getRuntimeinfo_taskPeriodMillis() {
    return runtimeinfo_taskPeriodMillis;
  }

  public long getUpdate_time_taskPeriodMillis() {
    return update_time_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Refrig_PeriodicTasks_timersConfigurationEvent{" + "version=" + version +
        ", agentmonitorservice_taskPeriodMillis=" + agentmonitorservice_taskPeriodMillis +
        ", cold1_FanCtrl_timer_taskPeriodMillis=" + cold1_FanCtrl_timer_taskPeriodMillis +
        ", cold2_FanCtrl_timer_taskPeriodMillis=" + cold2_FanCtrl_timer_taskPeriodMillis +
        ", compressor_state_taskPeriodMillis=" + compressor_state_taskPeriodMillis +
        ", cryo3_FanCtrl_timer_taskPeriodMillis=" + cryo3_FanCtrl_timer_taskPeriodMillis +
        ", cryo5_FanCtrl_timer_taskPeriodMillis=" + cryo5_FanCtrl_timer_taskPeriodMillis +
        ", heartbeat_taskPeriodMillis=" + heartbeat_taskPeriodMillis +
        ", monitor_check_taskPeriodMillis=" + monitor_check_taskPeriodMillis +
        ", monitor_publish_taskPeriodMillis=" + monitor_publish_taskPeriodMillis +
        ", monitor_update_taskPeriodMillis=" + monitor_update_taskPeriodMillis +
        ", runtimeinfo_taskPeriodMillis=" + runtimeinfo_taskPeriodMillis +
        ", update_time_taskPeriodMillis=" + update_time_taskPeriodMillis +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private long agentmonitorservice_taskPeriodMillis;

    private long cold1_FanCtrl_timer_taskPeriodMillis;

    private long cold2_FanCtrl_timer_taskPeriodMillis;

    private long compressor_state_taskPeriodMillis;

    private long cryo3_FanCtrl_timer_taskPeriodMillis;

    private long cryo5_FanCtrl_timer_taskPeriodMillis;

    private long heartbeat_taskPeriodMillis;

    private long monitor_check_taskPeriodMillis;

    private long monitor_publish_taskPeriodMillis;

    private long monitor_update_taskPeriodMillis;

    private long runtimeinfo_taskPeriodMillis;

    private long update_time_taskPeriodMillis;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder agentmonitorservice_taskPeriodMillis(long agentmonitorservice_taskPeriodMillis) {
      this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
      return this;
    }

    public Builder cold1_FanCtrl_timer_taskPeriodMillis(long cold1_FanCtrl_timer_taskPeriodMillis) {
      this.cold1_FanCtrl_timer_taskPeriodMillis = cold1_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder cold2_FanCtrl_timer_taskPeriodMillis(long cold2_FanCtrl_timer_taskPeriodMillis) {
      this.cold2_FanCtrl_timer_taskPeriodMillis = cold2_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder compressor_state_taskPeriodMillis(long compressor_state_taskPeriodMillis) {
      this.compressor_state_taskPeriodMillis = compressor_state_taskPeriodMillis;
      return this;
    }

    public Builder cryo3_FanCtrl_timer_taskPeriodMillis(long cryo3_FanCtrl_timer_taskPeriodMillis) {
      this.cryo3_FanCtrl_timer_taskPeriodMillis = cryo3_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder cryo5_FanCtrl_timer_taskPeriodMillis(long cryo5_FanCtrl_timer_taskPeriodMillis) {
      this.cryo5_FanCtrl_timer_taskPeriodMillis = cryo5_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder heartbeat_taskPeriodMillis(long heartbeat_taskPeriodMillis) {
      this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
      return this;
    }

    public Builder monitor_check_taskPeriodMillis(long monitor_check_taskPeriodMillis) {
      this.monitor_check_taskPeriodMillis = monitor_check_taskPeriodMillis;
      return this;
    }

    public Builder monitor_publish_taskPeriodMillis(long monitor_publish_taskPeriodMillis) {
      this.monitor_publish_taskPeriodMillis = monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder monitor_update_taskPeriodMillis(long monitor_update_taskPeriodMillis) {
      this.monitor_update_taskPeriodMillis = monitor_update_taskPeriodMillis;
      return this;
    }

    public Builder runtimeinfo_taskPeriodMillis(long runtimeinfo_taskPeriodMillis) {
      this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
      return this;
    }

    public Builder update_time_taskPeriodMillis(long update_time_taskPeriodMillis) {
      this.update_time_taskPeriodMillis = update_time_taskPeriodMillis;
      return this;
    }

    public Refrig_PeriodicTasks_timersConfigurationEvent build() {
      return new Refrig_PeriodicTasks_timersConfigurationEvent(priority, version, agentmonitorservice_taskPeriodMillis, cold1_FanCtrl_timer_taskPeriodMillis, cold2_FanCtrl_timer_taskPeriodMillis, compressor_state_taskPeriodMillis, cryo3_FanCtrl_timer_taskPeriodMillis, cryo5_FanCtrl_timer_taskPeriodMillis, heartbeat_taskPeriodMillis, monitor_check_taskPeriodMillis, monitor_publish_taskPeriodMillis, monitor_update_taskPeriodMillis, runtimeinfo_taskPeriodMillis, update_time_taskPeriodMillis);
    }
  }
}

==> org-lsst-sal-camera-2.5.8-sources.jar: org/lsst/sal/camera/event/Refrig_PeriodicTasks_timersConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Refrig_PeriodicTasks_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final long agentmonitorservice_taskPeriodMillis;

  private final long cold1_FanCtrl_timer_taskPeriodMillis;

  private final long cold2_FanCtrl_timer_taskPeriodMillis;

  private final long compressor_state_taskPeriodMillis;

  private final long cryo3_FanCtrl_timer_taskPeriodMillis;

  private final long cryo5_FanCtrl_timer_taskPeriodMillis;

  private final long heartbeat_taskPeriodMillis;

  private final long monitor_check_taskPeriodMillis;

  private final long monitor_publish_taskPeriodMillis;

  private final long monitor_update_taskPeriodMillis;

  private final long runtimeinfo_taskPeriodMillis;

  private final long update_time_taskPeriodMillis;

  public Refrig_PeriodicTasks_timersConfigurationEvent(String version,
      long agentmonitorservice_taskPeriodMillis, long cold1_FanCtrl_timer_taskPeriodMillis,
      long cold2_FanCtrl_timer_taskPeriodMillis, long compressor_state_taskPeriodMillis,
      long cryo3_FanCtrl_timer_taskPeriodMillis, long cryo5_FanCtrl_timer_taskPeriodMillis,
      long heartbeat_taskPeriodMillis, long monitor_check_taskPeriodMillis,
      long monitor_publish_taskPeriodMillis, long monitor_update_taskPeriodMillis,
      long runtimeinfo_taskPeriodMillis, long update_time_taskPeriodMillis) {
    this.version = version;
    this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
    this.cold1_FanCtrl_timer_taskPeriodMillis = cold1_FanCtrl_timer_taskPeriodMillis;
    this.cold2_FanCtrl_timer_taskPeriodMillis = cold2_FanCtrl_timer_taskPeriodMillis;
    this.compressor_state_taskPeriodMillis = compressor_state_taskPeriodMillis;
    this.cryo3_FanCtrl_timer_taskPeriodMillis = cryo3_FanCtrl_timer_taskPeriodMillis;
    this.cryo5_FanCtrl_timer_taskPeriodMillis = cryo5_FanCtrl_timer_taskPeriodMillis;
    this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
    this.monitor_check_taskPeriodMillis = monitor_check_taskPeriodMillis;
    this.monitor_publish_taskPeriodMillis = monitor_publish_taskPeriodMillis;
    this.monitor_update_taskPeriodMillis = monitor_update_taskPeriodMillis;
    this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
    this.update_time_taskPeriodMillis = update_time_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public long getAgentmonitorservice_taskPeriodMillis() {
    return agentmonitorservice_taskPeriodMillis;
  }

  public long getCold1_FanCtrl_timer_taskPeriodMillis() {
    return cold1_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCold2_FanCtrl_timer_taskPeriodMillis() {
    return cold2_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCompressor_state_taskPeriodMillis() {
    return compressor_state_taskPeriodMillis;
  }

  public long getCryo3_FanCtrl_timer_taskPeriodMillis() {
    return cryo3_FanCtrl_timer_taskPeriodMillis;
  }

  public long getCryo5_FanCtrl_timer_taskPeriodMillis() {
    return cryo5_FanCtrl_timer_taskPeriodMillis;
  }

  public long getHeartbeat_taskPeriodMillis() {
    return heartbeat_taskPeriodMillis;
  }

  public long getMonitor_check_taskPeriodMillis() {
    return monitor_check_taskPeriodMillis;
  }

  public long getMonitor_publish_taskPeriodMillis() {
    return monitor_publish_taskPeriodMillis;
  }

  public long getMonitor_update_taskPeriodMillis() {
    return monitor_update_taskPeriodMillis;
  }

  public long getRuntimeinfo_taskPeriodMillis() {
    return runtimeinfo_taskPeriodMillis;
  }

  public long getUpdate_time_taskPeriodMillis() {
    return update_time_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Refrig_PeriodicTasks_timersConfigurationEvent{" + "version=" + version +
        ", agentmonitorservice_taskPeriodMillis=" + agentmonitorservice_taskPeriodMillis +
        ", cold1_FanCtrl_timer_taskPeriodMillis=" + cold1_FanCtrl_timer_taskPeriodMillis +
        ", cold2_FanCtrl_timer_taskPeriodMillis=" + cold2_FanCtrl_timer_taskPeriodMillis +
        ", compressor_state_taskPeriodMillis=" + compressor_state_taskPeriodMillis +
        ", cryo3_FanCtrl_timer_taskPeriodMillis=" + cryo3_FanCtrl_timer_taskPeriodMillis +
        ", cryo5_FanCtrl_timer_taskPeriodMillis=" + cryo5_FanCtrl_timer_taskPeriodMillis +
        ", heartbeat_taskPeriodMillis=" + heartbeat_taskPeriodMillis +
        ", monitor_check_taskPeriodMillis=" + monitor_check_taskPeriodMillis +
        ", monitor_publish_taskPeriodMillis=" + monitor_publish_taskPeriodMillis +
        ", monitor_update_taskPeriodMillis=" + monitor_update_taskPeriodMillis +
        ", runtimeinfo_taskPeriodMillis=" + runtimeinfo_taskPeriodMillis +
        ", update_time_taskPeriodMillis=" + update_time_taskPeriodMillis +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private long agentmonitorservice_taskPeriodMillis;

    private long cold1_FanCtrl_timer_taskPeriodMillis;

    private long cold2_FanCtrl_timer_taskPeriodMillis;

    private long compressor_state_taskPeriodMillis;

    private long cryo3_FanCtrl_timer_taskPeriodMillis;

    private long cryo5_FanCtrl_timer_taskPeriodMillis;

    private long heartbeat_taskPeriodMillis;

    private long monitor_check_taskPeriodMillis;

    private long monitor_publish_taskPeriodMillis;

    private long monitor_update_taskPeriodMillis;

    private long runtimeinfo_taskPeriodMillis;

    private long update_time_taskPeriodMillis;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder agentmonitorservice_taskPeriodMillis(long agentmonitorservice_taskPeriodMillis) {
      this.agentmonitorservice_taskPeriodMillis = agentmonitorservice_taskPeriodMillis;
      return this;
    }

    public Builder cold1_FanCtrl_timer_taskPeriodMillis(long cold1_FanCtrl_timer_taskPeriodMillis) {
      this.cold1_FanCtrl_timer_taskPeriodMillis = cold1_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder cold2_FanCtrl_timer_taskPeriodMillis(long cold2_FanCtrl_timer_taskPeriodMillis) {
      this.cold2_FanCtrl_timer_taskPeriodMillis = cold2_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder compressor_state_taskPeriodMillis(long compressor_state_taskPeriodMillis) {
      this.compressor_state_taskPeriodMillis = compressor_state_taskPeriodMillis;
      return this;
    }

    public Builder cryo3_FanCtrl_timer_taskPeriodMillis(long cryo3_FanCtrl_timer_taskPeriodMillis) {
      this.cryo3_FanCtrl_timer_taskPeriodMillis = cryo3_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder cryo5_FanCtrl_timer_taskPeriodMillis(long cryo5_FanCtrl_timer_taskPeriodMillis) {
      this.cryo5_FanCtrl_timer_taskPeriodMillis = cryo5_FanCtrl_timer_taskPeriodMillis;
      return this;
    }

    public Builder heartbeat_taskPeriodMillis(long heartbeat_taskPeriodMillis) {
      this.heartbeat_taskPeriodMillis = heartbeat_taskPeriodMillis;
      return this;
    }

    public Builder monitor_check_taskPeriodMillis(long monitor_check_taskPeriodMillis) {
      this.monitor_check_taskPeriodMillis = monitor_check_taskPeriodMillis;
      return this;
    }

    public Builder monitor_publish_taskPeriodMillis(long monitor_publish_taskPeriodMillis) {
      this.monitor_publish_taskPeriodMillis = monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder monitor_update_taskPeriodMillis(long monitor_update_taskPeriodMillis) {
      this.monitor_update_taskPeriodMillis = monitor_update_taskPeriodMillis;
      return this;
    }

    public Builder runtimeinfo_taskPeriodMillis(long runtimeinfo_taskPeriodMillis) {
      this.runtimeinfo_taskPeriodMillis = runtimeinfo_taskPeriodMillis;
      return this;
    }

    public Builder update_time_taskPeriodMillis(long update_time_taskPeriodMillis) {
      this.update_time_taskPeriodMillis = update_time_taskPeriodMillis;
      return this;
    }

    public Refrig_PeriodicTasks_timersConfigurationEvent build() {
      return new Refrig_PeriodicTasks_timersConfigurationEvent(version, agentmonitorservice_taskPeriodMillis, cold1_FanCtrl_timer_taskPeriodMillis, cold2_FanCtrl_timer_taskPeriodMillis, compressor_state_taskPeriodMillis, cryo3_FanCtrl_timer_taskPeriodMillis, cryo5_FanCtrl_timer_taskPeriodMillis, heartbeat_taskPeriodMillis, monitor_check_taskPeriodMillis, monitor_publish_taskPeriodMillis, monitor_update_taskPeriodMillis, runtimeinfo_taskPeriodMillis, update_time_taskPeriodMillis);
    }
  }
}
